@@ -39,9 +39,9 @@ static GLuint create_vao_box(GLuint program)
 void DragSelection::Box::realize()
 {
     program = gl_create_program_from_resource(
-            "/net/carrotIndustries/horizon/canvas/shaders/"
+            "/org/horizon-eda/horizon/canvas/shaders/"
             "selection-vertex.glsl",
-            "/net/carrotIndustries/horizon/canvas/shaders/"
+            "/org/horizon-eda/horizon/canvas/shaders/"
             "selection-fragment.glsl",
             nullptr);
     vao = create_vao_box(program);
@@ -83,11 +83,11 @@ void DragSelection::Line::create_vao()
 void DragSelection::Line::realize()
 {
     program = gl_create_program_from_resource(
-            "/net/carrotIndustries/horizon/canvas/shaders/"
+            "/org/horizon-eda/horizon/canvas/shaders/"
             "selection-line-vertex.glsl",
-            "/net/carrotIndustries/horizon/canvas/shaders/"
+            "/org/horizon-eda/horizon/canvas/shaders/"
             "selection-line-fragment.glsl",
-            "/net/carrotIndustries/horizon/canvas/shaders/"
+            "/org/horizon-eda/horizon/canvas/shaders/"
             "selection-line-geometry.glsl");
     create_vao();
 
