@@ -5,6 +5,8 @@
 #include "nlohmann/json.hpp"
 #include "imp/action_catalog.hpp"
 #include "util/util.hpp"
+#include "util/str_util.hpp"
+#include <glibmm/ustring.h>
 
 namespace horizon {
 
@@ -318,6 +320,7 @@ void Core::rebuild(bool from_undo)
         assert(history_current + 1 == (int)history.size());
         history_push();
         history_current++;
+        history_trim();
     }
     s_signal_rebuilt.emit();
     signal_can_undo_redo().emit();
@@ -354,6 +357,15 @@ void Core::history_clear()
     signal_can_undo_redo().emit();
 }
 
+void Core::history_trim()
+{
+    const size_t history_max = 50;
+    while (history.size() > history_max) {
+        history.pop_front();
+        history_current--;
+    }
+}
+
 bool Core::can_redo() const
 {
     return history_current + 1 != (int)history.size();
@@ -458,6 +470,24 @@ void Core::sort_search_results(std::list<Core::SearchResult> &results, const Sea
         return a.location.y > b.location.y;
     });
 }
+
+void Core::SearchQuery::set_query(const std::string &q)
+{
+    query = Glib::ustring(q).casefold();
+    trim(query);
+}
+
+const std::string &Core::SearchQuery::get_query() const
+{
+    return query;
+}
+
+bool Core::SearchQuery::contains(const std::string &haystack) const
+{
+    Glib::ustring uhaystack(haystack);
+    return uhaystack.casefold().find(query) != Glib::ustring::npos;
+}
+
 ToolBase::ToolBase(Core *c, ToolID tid) : core(c), tool_id(tid)
 {
 }
