@@ -350,9 +350,14 @@ public:
 
     class SearchQuery {
     public:
-        std::string query;
+        void set_query(const std::string &q);
+        const std::string &get_query() const;
+        bool contains(const std::string &haystack) const;
         std::set<ObjectType> types;
         std::pair<Coordf, Coordf> area_visible;
+
+    private:
+        std::string query;
     };
 
     class SearchResult {
@@ -509,6 +514,7 @@ protected:
     virtual void history_push() = 0;
     virtual void history_load(unsigned int i) = 0;
     void history_clear();
+    void history_trim();
 
     bool property_transaction = false;
 
