@@ -13,8 +13,9 @@ CoreBoard::CoreBoard(const std::string &board_filename, const std::string &block
                      Pool &pool)
     : via_padstack_provider(via_dir, pool), block(Block::new_from_file(block_filename, pool)),
       brd(Board::new_from_file(board_filename, block, pool, via_padstack_provider)), rules(brd.rules),
-      fab_output_settings(brd.fab_output_settings), pdf_export_settings(brd.pdf_export_settings), colors(brd.colors),
-      m_board_filename(board_filename), m_block_filename(block_filename), m_via_dir(via_dir)
+      fab_output_settings(brd.fab_output_settings), pdf_export_settings(brd.pdf_export_settings),
+      step_export_settings(brd.step_export_settings), colors(brd.colors), m_board_filename(board_filename),
+      m_block_filename(block_filename), m_via_dir(via_dir)
 {
     m_pool = &pool;
     rebuild();
@@ -676,6 +677,7 @@ void CoreBoard::save(const std::string &suffix)
     brd.rules = rules;
     brd.fab_output_settings = fab_output_settings;
     brd.pdf_export_settings = pdf_export_settings;
+    brd.step_export_settings = step_export_settings;
     brd.colors = colors;
     auto j = brd.serialize();
     auto save_meta = s_signal_request_save_meta.emit();
