@@ -55,11 +55,11 @@ bool CorePackage::can_search_for_object_type(ObjectType ty) const
 std::list<Core::SearchResult> CorePackage::search(const SearchQuery &q)
 {
     std::list<Core::SearchResult> results;
-    if (q.query.size() == 0)
+    if (q.get_query().size() == 0)
         return results;
     if (q.types.count(ObjectType::PAD)) {
         for (const auto &it : package.pads) {
-            if (it.second.name.find(q.query) != std::string::npos) {
+            if (q.contains(it.second.name)) {
                 results.emplace_back(ObjectType::PAD, it.first);
                 auto &x = results.back();
                 x.location = it.second.placement.shift;
