@@ -69,7 +69,6 @@ public:
     void rebuild(bool from_undo = false) override;
     void commit() override;
     void revert() override;
-    void save() override;
 
     void add_sheet();
     void delete_sheet(const UUID &uu);
@@ -107,5 +106,7 @@ private:
     };
     void history_push() override;
     void history_load(unsigned int i) override;
+    void save(const std::string &suffix) override;
+    void delete_autosave() override;
 };
 } // namespace horizon
