@@ -5,5 +5,6 @@
 
 namespace horizon {
 void export_step(const std::string &filename, const Board &brd, class Pool &pool, bool include_models,
-                 std::function<void(std::string)> progress_cb, const Board::Colors *colors = nullptr);
+                 std::function<void(std::string)> progress_cb, const Board::Colors *colors = nullptr,
+                 const std::string &prefix = "");
 }
