@@ -717,6 +717,13 @@ const std::map<std::pair<ActionID, ToolID>, ActionCatalogItem> action_catalog =
         {{ActionID::TOOL, ToolID::POLYGON_TO_LINE_LOOP},
          {"Polygon to line loop", ActionGroup::GRAPHICS, ActionCatalogItem::AVAILABLE_EVERYWHERE,
           ActionCatalogItem::FLAGS_DEFAULT}},
+
+        {{ActionID::STEP_EXPORT_WINDOW, ToolID::NONE},
+         {"STEP export window", ActionGroup::BOARD, ActionCatalogItem::AVAILABLE_IN_BOARD,
+          ActionCatalogItem::FLAGS_DEFAULT}},
+
+        {{ActionID::EXPORT_STEP, ToolID::NONE},
+         {"Export STEP", ActionGroup::BOARD, ActionCatalogItem::AVAILABLE_IN_BOARD, ActionCatalogItem::FLAGS_DEFAULT}},
 };
 
 const std::vector<std::pair<ActionGroup, std::string>> action_group_catalog = {
@@ -805,6 +812,8 @@ const LutEnumStr<ActionID> action_lut = {
         ACTION_LUT_ITEM(BACKANNOTATE_CONNECTION_LINES),
         ACTION_LUT_ITEM(SELECT_MORE),
         ACTION_LUT_ITEM(SELECT_MORE_NO_VIA),
+        ACTION_LUT_ITEM(EXPORT_STEP),
+        ACTION_LUT_ITEM(STEP_EXPORT_WINDOW),
 };
 
 #define TOOL_LUT_ITEM(x)                                                                                               \
