@@ -140,7 +140,7 @@ MainWindow *MainWindow::create()
 {
     MainWindow *w;
     Glib::RefPtr<Gtk::Builder> x = Gtk::Builder::create();
-    x->add_from_resource("/net/carrotIndustries/horizon/window.ui");
+    x->add_from_resource("/org/horizon-eda/horizon/window.ui");
     x->get_widget_derived("mainWindow", w);
     return w;
 }
