@@ -1063,7 +1063,7 @@ PartWizard *PartWizard::create(const Package *p, const std::string &bp, class Po
     PartWizard *w;
     Glib::RefPtr<Gtk::Builder> x = Gtk::Builder::create();
     x->add_from_resource(
-            "/net/carrotIndustries/horizon/pool-prj-mgr/pool-mgr/part_wizard/"
+            "/org/horizon-eda/horizon/pool-prj-mgr/pool-mgr/part_wizard/"
             "part_wizard.ui");
     x->get_widget_derived("part_wizard", w, p, bp, po, aw);
     return w;
