@@ -26,9 +26,12 @@ void PoolGitBox::make_treeview(Gtk::TreeView *treeview)
         });
         treeview->append_column(*tvc);
     }
-
-    treeview->append_column("Name", list_columns.name);
-    treeview->append_column("Path", list_columns.path);
+    {
+        auto tvc = tree_view_append_column_ellipsis(treeview, "Name", list_columns.name, Pango::ELLIPSIZE_END);
+        tvc->set_min_width(200);
+        tvc->set_resizable(true);
+    }
+    tree_view_append_column_ellipsis(treeview, "Path", list_columns.path, Pango::ELLIPSIZE_START);
 
     treeview->signal_row_activated().connect([this, treeview](const Gtk::TreeModel::Path &path,
                                                               Gtk::TreeViewColumn *column) {
@@ -226,7 +229,7 @@ void PoolGitBox::refresh()
             update_store_from_db_prepare();
             git_diff_foreach(diff, &PoolGitBox::diff_file_cb_c, nullptr, nullptr, nullptr, this);
             update_store_from_db(diff_store);
-            diff_treeview->set_model(diff_store);
+            diff_treeview->set_model(diff_store_filtered);
             diff_box->set_visible(tree_master != tree_head);
         }
 
