@@ -186,6 +186,8 @@ void KeySequencesPreferencesEditor::handle_save()
 
         if (gtk_native_dialog_run(GTK_NATIVE_DIALOG(native)) == GTK_RESPONSE_ACCEPT) {
             filename = chooser->get_filename();
+            if (!endswith(filename, ".json"))
+                filename += ".json";
         }
     }
     if (filename.size()) {
