@@ -15,9 +15,9 @@ AboutDialog::AboutDialog() : Gtk::AboutDialog()
     authors.push_back("Lukas K. <lukas@horizon-eda.org>");
     set_authors(authors);
     set_license_type(Gtk::LICENSE_GPL_3_0);
-    set_copyright("Copyright © 2017-2019 Lukas K., et al.");
-    set_website("https://horizon-eda.readthedocs.io/");
-    set_website_label("Documentation");
+    set_copyright("Copyright © 2017-2020 Lukas K., et al.");
+    set_website("https://horizon-eda.org/");
+    set_website_label("horizon-eda.org");
     set_comments("a free EDA package");
 
     set_logo_icon_name("horizon-eda");
